<!DOCTYPE html>
<html lang="en">
  <head>
    <meta charset="utf-8">
    <title>Cronq Web Panel{% if title %} - {{title}}{% endif %}</title>
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta name="description" content="">
    <meta name="author" content="">

    <!-- Le styles -->
    <link href="/static/css/bootstrap.min.css" rel="stylesheet">
    <link href="/static/css/app.css" rel="stylesheet">
    <link href="/static/css/bootstrap-responsive.min.css" rel="stylesheet">
    <link href='https://fonts.googleapis.com/css?family=Roboto:400,300,300italic' rel='stylesheet' type='text/css'>
    <!-- HTML5 shim, for IE6-8 support of HTML5 elements -->
  </head>

  <body>

    <div class="container-narrow">

      <div class="masthead">
        <ul class="nav nav-pills pull-right">
          <li ><a href="{{url_for('failures')}}">Failures</a></li>
        </ul>
        <h3 class="muted"><a href="{{url_for("index")}}">CronQ</a></h3>
      </div>
      {% with messages = get_flashed_messages() %}
        {% if messages %}
          <div class="flashes alert alert-info">
          {% for message in messages %}
            {{ message }}
          {% endfor %}
          </div>
        {% endif %}
      {% endwith %}
      {% block main %}
      {% endblock main %}

    <!-- Le javascript
    ================================================== -->
    <!-- Placed at the end of the document so the pages load faster -->
    <script src="/static/js/jquery.js"></script>
    <script src="/static/js/bootstrap.min.js"></script>

    {% block javascript %}
    {% endblock javascript %}
  </body>
</html>
