{% extends "base.html" %}
{% block main %}

      <h2>Job: <a href="{{ url_for('job', id=job.id)}}">{{job.name}}</a></h2>
      <div id="events">
        {% for event in events %}
        <h3>Type: {{event.type}} {% if event.type == 'finished'%} Return Code: {{event.return_code}}{% endif %} </h3>
        <h4>ID: <a href="{{url_for("run_id", id=event.run_id)}}">{{event.run_id}}</a></h4>
        <h3>Time: {{event.datetime}} </h3>
        <h3>Host: {{event.host}} </h3>
        <hr>
        {% endfor %}
      </div>
{% endblock main %}
